## 3.0.1.20250801 (2025-08-01)

Split `tool.stubtest.platforms` metadata key (#13746)

Co-authored-by: Avasam <samuel.06@hotmail.com>
Co-authored-by: pre-commit-ci[bot] <66853113+pre-commit-ci[bot]@users.noreply.github.com>

## 3.0.1.20241117 (2024-11-17)

waitress: fixes for latest (#13027)

## 3.0.1.20241030 (2024-10-30)

[waitress] Update to 3.0.1 (#12917)

## 3.0.0.20241001 (2024-10-01)

Use `Mapping` for local Python namespace parameters (#12705)

## 3.0.0.20240423 (2024-04-23)

Bump waitress to 3.0.* (#11803)

## 2.1.4.20240421 (2024-04-21)

`waitress`: stubtest-complete and update usage of Any (#11796)

## 2.1.4.20240106 (2024-01-06)

Update typing_extensions imports in third-party stubs (#11245)

## 2.1.4.9 (2023-07-20)

Add an upstream_repository field to METADATA.toml (#10487)

Closes: #10478

## 2.1.4.8 (2023-05-10)

Add `partial_stub` metadata field (#10157)

## 2.1.4.7 (2023-03-29)

Remove unnecessary ellipsis expressions (#9976)

Ignore flake8 F821 warnings in stub files

## 2.1.4.6 (2023-03-28)

Add defaults to third-party stubs U-Z (#9971)

## 2.1.4.5 (2023-02-21)

Stubtest settings: change `ignore_missing_stub` default to `false` (#9779)

If you're reading about this commit from an autogenerated changelog entry, this should have no user-visible impact on how the stubs are interpreted by a type checker; it's just an internal change to how typeshed's tests work.

## 2.1.4.4 (2023-01-18)

Replace `Any` with `Incomplete` in many places (#9558)

## 2.1.4.3 (2022-11-16)

Always use `bool` and `Literal` for Python compat code (#9213)

## 2.1.4.2 (2022-11-13)

Run stubtest on Windows for waitress (#9181)

## 2.1.4.1 (2022-10-16)

Remove empty `__init__` methods from classes with 0 parents (#8907)

## 2.1.4 (2022-07-19)

Third-party stubs: enforce CamelCase for type alias names (#8256)

Co-authored-by: Jelle Zijlstra <jelle.zijlstra@gmail.com>

## 2.1.3 (2022-07-12)

Import `Match` and `Pattern` from `re`, not `typing` (#8277)

## 2.1.2 (2022-07-04)

Third-party stubs: audit more `Callable[<parameters>, Any]` annotations (#8233)

## 2.1.1 (2022-06-26)

Third-party stubs: audit `Callable[<parameters>, None]` annotations (#8175)

## 2.1.0 (2022-06-21)

Bump waitress to 2.1.* (#8113)

## 2.0.9 (2022-05-26)

Third-party stubs: fix several fictitious type aliases (#7958)

## 2.0.8 (2022-04-20)

Use `TypeAlias` for type aliases where possible, part II (#7667)

## 2.0.7 (2022-04-16)

Third-party stubs: import from `collections.abc` where possible (#7637)

## 2.0.5 (2021-12-28)

Use PEP 585 syntax wherever possible (#6717)

## 2.0.4 (2021-12-17)

Use stubtest 0.920 (#6589)

Co-authored-by: Alex Waygood <Alex.Waygood@Gmail.com>
Co-authored-by: Jelle Zijlstra <jelle.zijlstra@gmail.com>
Co-authored-by: Sebastian Rittau <srittau@rittau.biz>
Co-authored-by: Akuli <akuviljanen17@gmail.com>

## 2.0.3 (2021-11-26)

Add mypy error codes to '# type: ignore' comments (#6379)

## 2.0.2 (2021-11-23)

Reduce use of deprecated `typing` aliases (#6358)

## 2.0.1 (2021-10-15)

Use lowercase tuple where possible (#6170)

## 2.0.0 (2021-10-12)

Update remaining versions for third-party stubs (#6094)

Also remove the python2 markers of packages that don't list Python 2
as supported in the latest version.

Don't special case version '0.1'

Co-authored-by: Akuli <akuviljanen17@gmail.com>

